==> wglog-v1.2.zip: BOOT-INF/classes/static/js/fileWarnInfo.js <==
function searchByOrder(orderBy,orderType){
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/list?orderBy="+orderBy+"&orderType="+orderType+"&hostname="+$("#hostname").val();
}

function searchByAccount() {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/list?account="+$("#account").val();
}

function add() {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/edit";
}

function addBatch() {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/editBatch";
}


function stateList(id) {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnState/list?fileWarnId="+id;
}

function excelExport(id){
	window.open(SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/chartExcel?id="+id);
}

function view(id) {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/view?id="+id;
}

function stateView(id,fileWarnId) {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnState/view?id="+id+"&fileWarnId="+fileWarnId;
}

function stateViewMany(fileWarnId) {
	var chk_value =[];
	$("input[name='todo2']:checkbox").each(function() {
		if($(this).is(':checked')) {
			chk_value.push($(this).val());
		}
	});
	if(chk_value.length == 0){
		alert("请先选择需要合并展示的数据");
		return;
	}
	var vals = chk_value.join(",");
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnState/viewMany?id="+vals+"&fileWarnId="+fileWarnId;
}

function edit(id){
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/edit?id="+id;
}

function del(id) {
	if(confirm('您确定要删除此记录吗？')) {
		window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/del?id=" + id;
	}
}

//批量开始监控
function startMonitor(url) {
	var chk_value =[];
	$("input[name='todo2']:checkbox").each(function() {
		if($(this).is(':checked')) {
			chk_value.push($(this).val());
		}
	});
	if(chk_value.length == 0){
		alert("请先选择需要开始监控的数据");
		return;
	}
	if(confirm('您确定要开始监控吗？')) {
		var vals = chk_value.join(",");
		$.ajax(SERVER_SERVLET_CONTEXT_PATH + url,{
			type:"post",
			data:{"id":vals,"active":"1"},
			success:function(data){
				window.location.href = window.location.href;
			}
		});
	}
}

//批量停止监控
function stopMonitor(url) {
	var chk_value =[];
	$("input[name='todo2']:checkbox").each(function() {
		if($(this).is(':checked')) {
			chk_value.push($(this).val());
		}
	});
	if(chk_value.length == 0){
		alert("请先选择需要停止监控的数据");
		return;
	}
	if(confirm('您确定要停止监控吗？')) {
		var vals = chk_value.join(",");
		$.ajax(SERVER_SERVLET_CONTEXT_PATH + url,{
			type:"post",
			data:{"id":vals,"active":"2"},
			success:function(data){
				window.location.href = window.location.href;
			}
		});
	}
}

function resetParam(){
	$("#filePath").val("");
	$("#gatherLogContent").val("");
	$("#hostname").val("");
}

==> wglog-v1.3.zip: BOOT-INF/classes/static/js/fileWarnInfo.js <==
function searchByOrder(orderBy,orderType){
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/list?orderBy="+orderBy+"&orderType="+orderType+"&hostname="+$("#hostname").val();
}

function searchByAccount() {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/list?account="+$("#account").val();
}

function add() {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/edit";
}

function addBatch() {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/editBatch";
}


function stateList(id) {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnState/list?fileWarnId="+id;
}

function excelExport(id){
	window.open(SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/chartExcel?id="+id);
}

function view(id) {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/view?id="+id;
}

function stateView(id,fileWarnId) {
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnState/view?id="+id+"&fileWarnId="+fileWarnId;
}

function stateViewMany(fileWarnId) {
	var chk_value =[];
	$("input[name='todo2']:checkbox").each(function() {
		if($(this).is(':checked')) {
			chk_value.push($(this).val());
		}
	});
	if(chk_value.length == 0){
		alert("请先选择需要合并展示的数据");
		return;
	}
	var vals = chk_value.join(",");
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnState/viewMany?id="+vals+"&fileWarnId="+fileWarnId;
}

function edit(id){
	window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/edit?id="+id;
}

function del(id) {
	if(confirm('您确定要删除此记录吗？')) {
		window.location.href = SERVER_SERVLET_CONTEXT_PATH + "/fileWarnInfo/del?id=" + id;
	}
}

//批量开始监控
function startMonitor(url) {
	var chk_value =[];
	$("input[name='todo2']:checkbox").each(function() {
		if($(this).is(':checked')) {
			chk_value.push($(this).val());
		}
	});
	if(chk_value.length == 0){
		alert("请先选择需要开始监控的数据");
		return;
	}
	if(confirm('您确定要开始监控吗？')) {
		var vals = chk_value.join(",");
		$.ajax(SERVER_SERVLET_CONTEXT_PATH + url,{
			type:"post",
			data:{"id":vals,"active":"1"},
			success:function(data){
				window.location.href = window.location.href;
			}
		});
	}
}

//批量停止监控
function stopMonitor(url) {
	var chk_value =[];
	$("input[name='todo2']:checkbox").each(function() {
		if($(this).is(':checked')) {
			chk_value.push($(this).val());
		}
	});
	if(chk_value.length == 0){
		alert("请先选择需要停止监控的数据");
		return;
	}
	if(confirm('您确定要停止监控吗？')) {
		var vals = chk_value.join(",");
		$.ajax(SERVER_SERVLET_CONTEXT_PATH + url,{
			type:"post",
			data:{"id":vals,"active":"2"},
			success:function(data){
				window.location.href = window.location.href;
			}
		});
	}
}

function resetParam(){
	$("#filePath").val("");
	$("#gatherLogContent").val("");
	$("#hostname").val("");
}

function setPageSizeValue() {
	$("#pageSizeValue").val($("#pageSizeSelect").val());
	$("#searchForm").submit()
}
